Package: nlmixr2lib
Type: Package
Version: 0.3.2
Title: A Model Library for 'nlmixr2'
Description: A model library for 'nlmixr2'.  The models include
  (and plan to include) pharmacokinetic, pharmacodynamic, and
  disease models used in pharmacometrics.  Where applicable,
  references for each model are included in the meta-data for
  each individual model.  The package also includes model
  composition and modification functions to make model updates
  easier.
Authors@R: c(
  person("Richard","Hooijmaijers", email="richardhooijmaijers@gmail.com",role="aut"),
  person("Matthew","Fidler", email="matthew.fidler@gmail.com",role=c("aut"), comment=c(ORCID="0000-0001-8538-6691")),
  person("Bill", "Denney", email="wdenney@humanpredictions.com", role=c("aut", "cre"), comment=c(ORCID="0000-0002-5759-428X")),
  person("Kiranmayi", "Vedantham", email="kiranmayi.vedantham@gmail.com", role=c("aut"),comment=c(ORCID="0009-0003-0828-6445"))
  )
Depends: R (>= 4.1)
Imports: checkmate, cli, methods, nlmixr2est, rxode2 (>= 2.0.12)
License: GPL (>= 2)
LazyData: true
RoxygenNote: 7.3.3
VignetteBuilder: knitr
URL: https://github.com/nlmixr2/nlmixr2lib,
        https://nlmixr2.github.io/nlmixr2lib/
Encoding: UTF-8
Language: en-US
Suggests: covr, dplyr, knitr, rmarkdown, testthat (>= 3.0.0), qs2,
        tidyr, ggplot2, withr
Config/testthat/edition: 3
Config/testthat/parallel: true
NeedsCompilation: no
Packaged: 2026-01-17 21:31:30 UTC; bill
Author: Richard Hooijmaijers [aut],
  Matthew Fidler [aut] (ORCID: <https://orcid.org/0000-0001-8538-6691>),
  Bill Denney [aut, cre] (ORCID: <https://orcid.org/0000-0002-5759-428X>),
  Kiranmayi Vedantham [aut] (ORCID:
    <https://orcid.org/0009-0003-0828-6445>)
Maintainer: Bill Denney <wdenney@humanpredictions.com>
Repository: CRAN
Date/Publication: 2026-01-18 06:10:18 UTC
Built: R 4.6.0; ; 2026-04-25 13:58:51 UTC; unix
