# Generated by roxygen2: do not edit by hand

S3method(searchReplaceHelper,"function")
S3method(searchReplaceHelper,call)
S3method(searchReplaceHelper,default)
export(addBaseline1exp)
export(addBaselineConst)
export(addBaselineExp)
export(addBaselineLin)
export(addBioavailability)
export(addCmtProp)
export(addDepot)
export(addDirToModelDb)
export(addDirectLin)
export(addDur)
export(addEffectCmtLin)
export(addEta)
export(addFileToModelDb)
export(addIndirect)
export(addIndirectLin)
export(addIni)
export(addLag)
export(addLogEstimates)
export(addRate)
export(addResErr)
export(addTransit)
export(addWeibullAbs)
export(assertCompartmentExists)
export(assertCompartmentName)
export(assertParameterValue)
export(assertRxUi)
export(assertRxUiEstimatedResiduals)
export(assertRxUiMixedOnly)
export(assertRxUiMuRefOnly)
export(assertRxUiNormal)
export(assertRxUiPopulationOnly)
export(assertRxUiPrediction)
export(assertRxUiRandomOnIdOnly)
export(assertRxUiSingleEndpoint)
export(assertRxUiTransformNormal)
export(assertVariableName)
export(blankCombine)
export(camelCombine)
export(combinePaste2)
export(convertEmax)
export(convertEmaxHill)
export(convertKinR0)
export(convertLogLin)
export(convertMM)
export(convertQuad)
export(defaultCombine)
export(dotCombine)
export(expit)
export(fakeCc)
export(logit)
export(modellib)
export(pkTrans)
export(readModelDb)
export(removeDepot)
export(removeLinesAndInis)
export(removeTransit)
export(searchReplace)
export(searchReplaceHelper)
export(setCombineType)
export(snakeCombine)
export(updateOncologyXenograftSimeoni2004)
importFrom(rxode2,assertCompartmentExists)
importFrom(rxode2,assertCompartmentName)
importFrom(rxode2,assertParameterValue)
importFrom(rxode2,assertRxUi)
importFrom(rxode2,assertRxUiEstimatedResiduals)
importFrom(rxode2,assertRxUiMixedOnly)
importFrom(rxode2,assertRxUiMuRefOnly)
importFrom(rxode2,assertRxUiNormal)
importFrom(rxode2,assertRxUiPopulationOnly)
importFrom(rxode2,assertRxUiPrediction)
importFrom(rxode2,assertRxUiRandomOnIdOnly)
importFrom(rxode2,assertRxUiSingleEndpoint)
importFrom(rxode2,assertRxUiTransformNormal)
importFrom(rxode2,assertVariableName)
importFrom(rxode2,expit)
importFrom(rxode2,logit)
